package com.ruoyi.system.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ActSuppliesRole;
import com.ruoyi.system.service.IActSuppliesRoleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 导入规则Controller
 * 
 * @author dongjg
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/system/suppliesrole")
public class ActSuppliesRoleController extends BaseController
{
    @Autowired
    private IActSuppliesRoleService actSuppliesRoleService;

    /**
     * 查询导入规则列表
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:list')")
    @GetMapping("/list")
    public TableDataInfo list(ActSuppliesRole actSuppliesRole)
    {
        startPage();
        List<ActSuppliesRole> list = actSuppliesRoleService.selectActSuppliesRoleList(actSuppliesRole);
        return getDataTable(list);
    }

    /**
     * 导出导入规则列表
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:export')")
    @Log(title = "导入规则", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ActSuppliesRole actSuppliesRole)
    {
        List<ActSuppliesRole> list = actSuppliesRoleService.selectActSuppliesRoleList(actSuppliesRole);
        ExcelUtil<ActSuppliesRole> util = new ExcelUtil<ActSuppliesRole>(ActSuppliesRole.class);
        return util.exportExcel(list, "导入规则数据");
    }

    /**
     * 获取导入规则详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(actSuppliesRoleService.selectActSuppliesRoleById(id));
    }

    /**
     * 新增导入规则
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:add')")
    @Log(title = "导入规则", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ActSuppliesRole actSuppliesRole)
    {
        return toAjax(actSuppliesRoleService.insertActSuppliesRole(actSuppliesRole));
    }

    /**
     * 修改导入规则
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:edit')")
    @Log(title = "导入规则", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ActSuppliesRole actSuppliesRole)
    {
        return toAjax(actSuppliesRoleService.updateActSuppliesRole(actSuppliesRole));
    }

    /**
     * 删除导入规则
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesrole:remove')")
    @Log(title = "导入规则", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(actSuppliesRoleService.deleteActSuppliesRoleByIds(ids));
    }
}
